<?php

namespace Drp\SimpleCms\Http\Controllers\Admin;

use Drp\SimpleCms\AllContent;
use Drp\SimpleCms\Contracts\ContentFactory;
use Drp\SimpleCms\Contracts\Publishable;
use Illuminate\Foundation\Auth\Access\AuthorizesRequests;
use Illuminate\Routing\Controller;

/**
 * Class ReviewController
 * @package Drp\SimpleCms
 */
class ReviewController extends Controller
{

    use AuthorizesRequests;

    /**
     * @var ContentFactory
     */
    private $contentFactory;

    /**
     * ResetController constructor.
     * @param ContentFactory $contentFactory
     */
    public function __construct(ContentFactory $contentFactory)
    {
        $this->contentFactory = $contentFactory;
    }

    /**
     * Show all the content that are in review
     *
     * @param AllContent $allContent
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function index(AllContent $allContent)
    {
        $this->authorize('publish', Publishable::class);

        $content = $allContent->contentInReview();

        return view('simpleCms::review', compact('content'));
    }

    /**
     * Mark the given$content as in review
     *
     * @param string $contentType
     * @param integer $versionId
     * @return \Illuminate\Http\RedirectResponse
     */
    public function update($contentType, $versionId)
    {
        $content = $this->contentFactory->byTypeAndVersionId($contentType, $versionId);

        $this->authorize('review', $content);

        $content->updateReviewStatus();

        flash()->success(
            trans('simpleCms::content.' . ($content->isInReview() ? 'review-sent' : 'review-rejected'))
        );

        return redirect()->back();
    }
}
