<?php

namespace Drp\SimpleCms\Test\Unit;

use Drp\SimpleCms\Content;
use Drp\SimpleCms\ContentFactory;
use Drp\SimpleCms\Test\TestCase;
use Drp\SimpleCms\Test\Support\Fakes\TestContent;
use InvalidArgumentException;

/**
 * Class ContentFactoryTest
 * @package Tests\Unit
 */
class ContentFactoryTest extends TestCase
{

    /**
     * @test
     */
    public function an_exception_is_thrown_if_the_content_type_is_not_valid()
    {
        try {
            ContentFactory::makeContentClass('invalid', 1);
        } catch (InvalidArgumentException $exception) {
            $this->assertEquals(trans('content.errors.name-invalid'), $exception->getMessage());
            return;
        };

        $this->fail('Exception was not thrown, and invalid content type was allowed');
    }

    /**
     * @test
     */
    public function it_can_return_a_content_class_based_on_type()
    {
        $this->assertInstanceOf(Content::class, ContentFactory::makeContentClass('test-content'));
    }

    /**
     * @test
     */
    public function it_can_return_a_content_label()
    {
        $this->assertEquals('Test content label', ContentFactory::contentLabel('test-content'));
        $this->assertEquals('Test content labels', ContentFactory::contentLabel('test-content', true));
        $this->assertEquals('test content label', ContentFactory::contentLabel('test-content', false, true));
    }

    /**
     * @test
     */
    public function it_returns_the_latest_content_based_on_type_and_id()
    {
        $content = TestContent::create();
        $factory = app(ContentFactory::class);

        $this->assertSameModel($content, $factory->latestVersionByTypeAndContentId('test-content', 1));
    }

    /**
     * @test
     */
    public function it_can_get_by_model_id_and_type()
    {
        $content = TestContent::create();

        $contentFactory = $this->app->make(ContentFactory::class);

        $actual = $contentFactory->byTypeAndVersionId('test-content', 1);

        $this->assertSameModel($content, $actual);
    }

}
